@@ -21,6 +21,7 @@
 
 #include "config.h"
 
+#include <string.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
@@ -40,6 +41,9 @@ struct _GsdX11DeviceManagerClass
 	GsdDeviceManagerClass parent_class;
 };
 
+GsdDevice  * gsd_x11_device_manager_lookup_gdk_device (GsdDeviceManager *manager,
+						       GdkDevice	*gdk_device);
+
 G_DEFINE_TYPE (GsdX11DeviceManager, gsd_x11_device_manager, GSD_TYPE_DEVICE_MANAGER)
 
 static GsdDeviceType
@@ -51,10 +55,13 @@ device_get_device_type (GdkDevice *gdk_device)
 
 	switch (source) {
 	case GDK_SOURCE_MOUSE:
+	case GDK_SOURCE_TRACKPOINT:
 		return GSD_DEVICE_TYPE_MOUSE;
 	case GDK_SOURCE_PEN:
 	case GDK_SOURCE_ERASER:
 	case GDK_SOURCE_CURSOR:
+		if (strstr (gdk_device_get_name (gdk_device), "pad"))
+			return GSD_DEVICE_TYPE_TABLET | GSD_DEVICE_TYPE_PAD;
 		return GSD_DEVICE_TYPE_TABLET;
 	case GDK_SOURCE_KEYBOARD:
 		return GSD_DEVICE_TYPE_KEYBOARD;
@@ -62,10 +69,11 @@ device_get_device_type (GdkDevice *gdk_device)
 		return GSD_DEVICE_TYPE_TOUCHSCREEN;
 	case GDK_SOURCE_TOUCHPAD:
 		return GSD_DEVICE_TYPE_TOUCHPAD;
-	default:
-		g_warning ("Unhandled input source %d\n", source);
+	case GDK_SOURCE_TABLET_PAD:
+		return GSD_DEVICE_TYPE_PAD;
 	}
 
+	g_warning ("Unhandled input source %d\n", source);
 	return 0;
 }
 
@@ -112,7 +120,11 @@ add_device (GsdX11DeviceManager *manager,
 	/* Takes ownership of device_file */
 	g_hash_table_insert (manager->gdk_devices, gdk_device, device_file);
 
-	if (!g_hash_table_lookup (manager->devices, device_file)) {
+	device = g_hash_table_lookup (manager->devices, device_file);
+
+	if (device) {
+		g_signal_emit_by_name (manager, "device-changed", device);
+	} else {
 		device = create_device (gdk_device, device_file);
 		g_hash_table_insert (manager->devices, g_strdup (device_file), device);
 		g_signal_emit_by_name (manager, "device-added", device);
@@ -211,51 +223,20 @@ gsd_x11_device_manager_class_init (GsdX11DeviceManagerClass *klass)
 	GsdDeviceManagerClass *manager_class = GSD_DEVICE_MANAGER_CLASS (klass);
 
 	manager_class->list_devices = gsd_x11_device_manager_list_devices;
-}
-
-GdkDevice **
-gsd_x11_device_manager_get_gdk_devices (GsdX11DeviceManager *manager,
-					GsdDevice	    *device,
-					guint		    *n_gdk_devices)
-{
-	const gchar *device_node;
-	GPtrArray *gdk_devices;
-	GdkDevice *gdk_device;
-	GHashTableIter iter;
-
-	if (n_gdk_devices)
-		*n_gdk_devices = 0;
-
-	g_return_val_if_fail (GSD_IS_X11_DEVICE_MANAGER (manager), NULL);
-	g_return_val_if_fail (GSD_IS_DEVICE (device), NULL);
-
-	gdk_devices = g_ptr_array_new ();
-	g_hash_table_iter_init (&iter, manager->gdk_devices);
-
-	while (g_hash_table_iter_next (&iter, (gpointer *) &gdk_device, (gpointer *) &device_node)) {
-		if (g_strcmp0 (gsd_device_get_device_file (device), device_node) == 0)
-			g_ptr_array_add (gdk_devices, gdk_device);
-	}
-
-	if (n_gdk_devices)
-		*n_gdk_devices = gdk_devices->len;
-
-	return (GdkDevice **) g_ptr_array_free (gdk_devices, FALSE);
+	manager_class->lookup_device = gsd_x11_device_manager_lookup_gdk_device;
 }
 
 GsdDevice *
-gsd_x11_device_manager_lookup_gdk_device (GsdX11DeviceManager *manager,
-					  GdkDevice	      *gdk_device)
+gsd_x11_device_manager_lookup_gdk_device (GsdDeviceManager *manager,
+					  GdkDevice	   *gdk_device)
 {
+	GsdX11DeviceManager *manager_x11 = GSD_X11_DEVICE_MANAGER (manager);
 	const gchar *device_node;
 
-	g_return_val_if_fail (GSD_IS_X11_DEVICE_MANAGER (manager), NULL);
-	g_return_val_if_fail (GDK_IS_DEVICE (gdk_device), NULL);
-
-	device_node = g_hash_table_lookup (manager->gdk_devices, gdk_device);
+	device_node = g_hash_table_lookup (manager_x11->gdk_devices, gdk_device);
 
 	if (!device_node)
 		return NULL;
 
-	return g_hash_table_lookup (manager->devices, device_node);
+	return g_hash_table_lookup (manager_x11->devices, device_node);
 }
